import React, { useState, useEffect } from 'react';
import { X, Timer, Cloud, FileText, Scissors } from './Icons';
import { MowingFormData, Mower } from '../types/zone';
import { api } from '../services/api';

interface MowingModalProps {
  zoneName: string;
  onSubmit: (data: MowingFormData) => void;
  onCancel: () => void;
  loading?: boolean;
}

const MowingModal: React.FC<MowingModalProps> = ({ 
  zoneName, 
  onSubmit, 
  onCancel, 
  loading = false 
}) => {
  const [formData, setFormData] = useState<MowingFormData>({
    notes: '',
    duration: undefined,
    weather: '',
    mowerId: undefined,
  });
  const [mowers, setMowers] = useState<Mower[]>([]);
  const [loadingMowers, setLoadingMowers] = useState(true);

  useEffect(() => {
    loadMowers();
  }, []);

  const loadMowers = async () => {
    try {
      const data = await api.getMowers();
      setMowers(data);
      // Auto-select first mower if only one exists
      if (data.length === 1) {
        setFormData(prev => ({ ...prev, mowerId: data[0].id }));
      }
    } catch (error) {
      console.error('Failed to load mowers:', error);
    } finally {
      setLoadingMowers(false);
    }
  };

  const handleSubmit = (e: React.FormEvent) => {
    e.preventDefault();
    onSubmit(formData);
  };

  const weatherOptions = [
    'Солнечно',
    'Переменная облачность',
    'Облачно',
    'Пасмурно',
    'Небольшой дождь',
    'Ветренно',
    'Жарко',
    'Холодно',
    'Влажно'
  ];

  const getMowerIcon = (type: string) => {
    switch (type.toLowerCase()) {
      case 'battery':
        return '🔋';
      case 'electric':
        return '⚡';
      case 'gas':
      case 'petrol':
        return '⛽';
      default:
        return '🚜';
    }
  };

  return (
    <div className="fixed inset-0 bg-black bg-opacity-50 flex items-center justify-center p-4 z-50">
      <div className="bg-white rounded-lg shadow-xl max-w-md w-full">
        <div className="flex items-center justify-between p-6 border-b">
          <h2 className="text-xl font-semibold text-gray-900">
            Отметить как скошенное: {zoneName}
          </h2>
          <button
            onClick={onCancel}
            className="text-gray-400 hover:text-gray-600 transition-colors duration-200"
          >
            <X className="h-6 w-6" />
          </button>
        </div>

        <form onSubmit={handleSubmit} className="p-6 space-y-6">
          {/* Mower Selection */}
          <div>
            <label htmlFor="mowerId" className="block text-sm font-medium text-gray-700 mb-2">
              <Scissors className="h-4 w-4 inline mr-2" />
              Использована косилка
            </label>
            {loadingMowers ? (
                <div className="w-full px-3 py-2 border border-gray-300 rounded-md bg-gray-50">
                  <span className="text-gray-500">Loading mowers...</span>
                </div>
            ) : (
                <select
                    id="mowerId"
                    value={formData.mowerId || ''}
                    onChange={(e) => setFormData(prev => ({
                      ...prev,
                      mowerId: e.target.value ? parseInt(e.target.value) : undefined
                    }))}
                    className="w-full px-3 py-2 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-green-500 focus:border-transparent"
                    required
                >
                  <option value="">Выбор триммера</option>
                  {mowers.map(mower => (
                      <option key={mower.id} value={mower.id}>
                        {getMowerIcon(mower.type)} {mower.name} ({mower.type})
                      </option>
                  ))}
                </select>
            )}
            {mowers.length === 0 && !loadingMowers && (
                <p className="text-xs text-amber-600 mt-1">
                  No mowers found. You can still record the mowing session without selecting a mower.
                </p>
            )}
          </div>

          {/* Duration */}
          <div>
            <label htmlFor="duration" className="block text-sm font-medium text-gray-700 mb-2">
              <Timer className="h-4 w-4 inline mr-2" />
              Длительность (минуты)
            </label>
            <input
              type="number"
              id="duration"
              value={formData.duration || ''}
              onChange={(e) => setFormData(prev => ({ 
                ...prev, 
                duration: e.target.value ? parseInt(e.target.value) : undefined 
              }))}
              className="w-full px-3 py-2 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-green-500 focus:border-transparent"
              min="1"
              max="480"
              placeholder="например, 45"
            />
            <p className="text-xs text-gray-500 mt-1">Необязательно - сколько времени это заняло?</p>
          </div>

          {/* Weather */}
          <div>
            <label htmlFor="weather" className="block text-sm font-medium text-gray-700 mb-2">
              <Cloud className="h-4 w-4 inline mr-2" />
              Погодные условия
            </label>
            <select
              id="weather"
              value={formData.weather || ''}
              onChange={(e) => setFormData(prev => ({ ...prev, weather: e.target.value }))}
              className="w-full px-3 py-2 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-green-500 focus:border-transparent"
            >
              <option value="">Выбор погоды (не обязательно)</option>
              {weatherOptions.map(weather => (
                <option key={weather} value={weather}>{weather}</option>
              ))}
            </select>
          </div>

          {/* Notes */}
          <div>
            <label htmlFor="notes" className="block text-sm font-medium text-gray-700 mb-2">
              <FileText className="h-4 w-4 inline mr-2" />
              Заметки
            </label>
            <textarea
              id="notes"
              value={formData.notes || ''}
              onChange={(e) => setFormData(prev => ({ ...prev, notes: e.target.value }))}
              className="w-full px-3 py-2 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-green-500 focus:border-transparent"
              rows={3}
              placeholder="Какие-либо замечания, проблемы или специальные замечания..."
            />
            <p className="text-xs text-gray-500 mt-1">Необязательно - записывайте любые особые наблюдения.</p>
          </div>

          {/* Form Actions */}
          <div className="flex gap-3 pt-4">
            <button
              type="button"
              onClick={onCancel}
              className="flex-1 py-2 px-4 border border-gray-300 text-gray-700 rounded-md hover:bg-gray-50 transition-colors duration-200"
            >
              Отмена
            </button>
            <button
              type="submit"
              disabled={loading}
              className="flex-1 py-2 px-4 bg-green-600 text-white rounded-md hover:bg-green-700 disabled:opacity-50 disabled:cursor-not-allowed transition-colors duration-200"
            >
              {loading ? 'Записывается...' : 'Отметить'}
            </button>
          </div>
        </form>
      </div>
    </div>
  );
};

export default MowingModal;